about summary refs log tree commit homepage
path: root/lib/PublicInbox/Repobrowse.pm
diff options
context:
space:
mode:
authorEric Wong <e@80x24.org>2017-02-17 03:31:16 +0000
committerEric Wong <e@80x24.org>2017-02-17 03:31:16 +0000
commit8d83eab9d95348e996a2d1f92d970ddc0bf4f85b (patch)
treeeb71f3f484084b2c1b4bc50446ad035e8b95e111 /lib/PublicInbox/Repobrowse.pm
parente7dc3224ad0b497da6ef242e3a9c612c5702514e (diff)
downloadpublic-inbox-8d83eab9d95348e996a2d1f92d970ddc0bf4f85b.tar.gz
This name is shorter and matches terminology in gitweb and
other popular git web viewers.
Diffstat (limited to 'lib/PublicInbox/Repobrowse.pm')
-rw-r--r--lib/PublicInbox/Repobrowse.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/PublicInbox/Repobrowse.pm b/lib/PublicInbox/Repobrowse.pm
index 34ffd542..de5bd364 100644
--- a/lib/PublicInbox/Repobrowse.pm
+++ b/lib/PublicInbox/Repobrowse.pm
@@ -23,7 +23,7 @@ use warnings;
 use URI::Escape qw(uri_escape_utf8);
 use PublicInbox::RepoConfig;
 
-my %CMD = map { lc($_) => $_ } qw(Log Commit Tree Patch Blob Plain Tag Atom
+my %CMD = map { lc($_) => $_ } qw(Log Commit Tree Patch Blob Raw Tag Atom
         Diff Snapshot);
 my %VCS = (git => 'Git');
 my %LOADED;
@@ -57,7 +57,7 @@ sub base_url ($) {
 
 # Remove trailing slash in URLs which regular humans are likely to read
 # in an attempt to improve cache hit ratios.  Do not redirect
# plain|patch|blob|fallback endpoints since those could be using
 # automated tools which may not follow redirects automatically
 # (e.g. curl does not follow 301 unless given "-L")
 my %NO_TSLASH = map { $_ => 1 } qw(Log Commit Tree Summary Tag);
@@ -57,7 +57,7 @@ sub base_url ($) {
 # Remove trailing slash in URLs which regular humans are likely to read
 # in an attempt to improve cache hit ratios.  Do not redirect
-# plain|patch|blob|fallback endpoints since those could be using
+# raw|patch|blob|fallback endpoints since those could be using
 # automated tools which may not follow redirects automatically
 # (e.g. curl does not follow 301 unless given "-L")